@@ -36,13 +36,13 @@ def user_clean_name(user: str) -> str:
 
 
 def user_check(db: Connection, user: str, field: str, value: str) -> bool:
-    field_value: List[str] = select(db, "USERS", [field], "USERNAME", user)[0][0].split(",")
+    field_value: List[str] = next(select(db, "USERS", [field], "USERNAME", user))[0].split(",")
 
     return value in filter(len, field_value)
 
 
 def user_add(db: Connection, user: str, field: str, add_value: str):
-    field_old: List[str] = select(db, "USERS", [field], "USERNAME", user)[0][0].split(",")
+    field_old: List[str] = next(select(db, "USERS", [field], "USERNAME", user))[0].split(",")
     field_old = list(filter(len, field_old))
 
     if add_value in field_old:
